## 0.3.0
Explicit Django 5 support

## 0.2.0
Explicit django 4 support

### 0.1.1
Add explicit django 3.1,3.2 support

## 0.1.0
You can now pass relative urls to `is_visible(url, request)`.

### 0.0.1
Bug fix

# 0.0.0